Increase FONT_MAXNO from 0x2f to 0x40, to ensure the fonts[] array
[u/mdw/putty] / psftp.h
diff --git a/psftp.h b/psftp.h
index 8d9391c..e6ad00f 100644 (file)
--- a/psftp.h
+++ b/psftp.h
@@ -85,15 +85,17 @@ void gui_enable(char *arg);
  */
 typedef struct RFile RFile;
 typedef struct WFile WFile;
/* Output params size, mtime and atime can all be NULL if desired */
 RFile *open_existing_file(char *name, uint64 *size,
-                         unsigned long *mtime, unsigned long *atime);
+                         unsigned long *mtime, unsigned long *atime,
+                          long *perms);
 WFile *open_existing_wfile(char *name, uint64 *size);
 /* Returns <0 on error, 0 on eof, or number of bytes read, as usual */
 int read_from_file(RFile *f, void *buffer, int length);
 /* Closes and frees the RFile */
 void close_rfile(RFile *f);
-WFile *open_new_file(char *name);
+WFile *open_new_file(char *name, long perms);
 /* Returns <0 on error, 0 on eof, or number of bytes written, as usual */
 int write_to_file(WFile *f, void *buffer, int length);
 void set_file_times(WFile *f, unsigned long mtime, unsigned long atime);
@@ -85,15 +85,17 @@ void gui_enable(char *arg);
 typedef struct RFile RFile;
 typedef struct WFile WFile;
-/* Output params size, mtime and atime can all be NULL if desired */
+/* Output params size, perms, mtime and atime can all be NULL if
+ * desired. perms will be -1 if the OS does not support POSIX permissions. */
 RFile *open_existing_file(char *name, uint64 *size,